## AWS::RoboMaker Construct Library

This module is part of the [AWS Cloud Development Kit](https://github.com/awslabs/aws-cdk) project.

```ts
import robomaker = require('@aws-cdk/aws-robomaker');
```

